import argparse
import os
import sys
import traceback
from multiprocessing import cpu_count
from multiprocessing.pool import ThreadPool
from threading import Lock
from typing import BinaryIO

from win2xcur.parser import open_blob
from win2xcur.writer import to_smart


def main() -> None:
    parser = argparse.ArgumentParser(description='Converts Windows cursors to X11 cursors.')
    parser.add_argument('files', type=argparse.FileType('rb'), nargs='+',
                        help='X11 cursor files to convert (no extension)')
    parser.add_argument('-o', '--output', '--output-dir', default=os.curdir,
                        help='Directory to store converted cursor files.')

    args = parser.parse_args()
    print_lock = Lock()

    def process(file: BinaryIO) -> None:
        name = file.name
        blob = file.read()
        try:
            cursor = open_blob(blob)
        except Exception:
            with print_lock:
                print('Error occurred while processing %s:' % (name,), file=sys.stderr)
                traceback.print_exc()
        else:
            ext, result = to_smart(cursor.frames)
            output = os.path.join(args.output, os.path.basename(name) + ext)
            with open(output, 'wb') as f:
                f.write(result)

    with ThreadPool(cpu_count()) as pool:
        pool.map(process, args.files)


if __name__ == '__main__':
    main()



from win2xcur.writer.windows import to_ani, to_cur, to_smart
from win2xcur.writer.x11 import to_x11

__all__ = ['to_ani', 'to_cur', 'to_smart', 'to_x11']

CONVERTERS = {
    'x11': (to_x11, ''),
    'ani': (to_ani, '.ani'),
    'cur': (to_cur, '.cur'),
}



import ctypes

from wand.api import library
from wand.image import Image
from wand.sequence import SingleImage

MagickImportImagePixels = library['MagickImportImagePixels']
MagickImportImagePixels.argtypes = (
    ctypes.c_void_p, ctypes.c_ssize_t, ctypes.c_ssize_t, ctypes.c_size_t,
    ctypes.c_size_t, ctypes.c_char_p, ctypes.c_int, ctypes.c_void_p
)
StorageType = ('undefined', 'char', 'double', 'float',
               'integer', 'long', 'quantum', 'short')


def image_from_pixels(blob: bytes, width: int, height: int, pixel_format: str, pixel_size: str) -> SingleImage:
    image = Image(width=width, height=height)
    MagickImportImagePixels(image.wand, 0, 0, width, height, pixel_format.encode('ascii'),
                            StorageType.index(pixel_size), blob)
    return image.sequence[0]
